@@ -20,7 +20,7 @@
 #       MA 02110-1301, USA.
 
 import os, sys, ConfigParser, gtk, pango, locale, subprocess, base64, webbrowser
-import cons, support, codeboxes, pgsc_spellcheck
+import cons, support, exports, codeboxes, pgsc_spellcheck
 if cons.HAS_APPINDICATOR: import appindicator
 
 ICONS_SIZE = {1: gtk.ICON_SIZE_MENU, 2: gtk.ICON_SIZE_SMALL_TOOLBAR, 3: gtk.ICON_SIZE_LARGE_TOOLBAR,
@@ -33,7 +33,7 @@ COLOR_PALETTE_DEFAULT = ["#000000", "#ffffff", "#7f7f7f", "#ff0000", "#a020f0",
                          "#0000ff", "#add8e6", "#00ff00", "#ffff00", "#ffa500",
                          "#e6e6fa", "#a52a2a", "#8b6914", "#1e90ff", "#ffc0cb",
                          "#90ee90", "#1a1a1a", "#4d4d4d", "#bfbfbf", "#e5e5e5"]
-SPECIAL_CHARS_DEFAULT = "“”„•◇▪▸☐☑☒★…‰€©®™°↓↑→←↔↵⇓⇑⇒⇐⇔»«▼▲►◄≤≥≠≈±¹²³½¼⅛×÷∞ø∑√∫ΔδΠπΣΦΩωαβγεηλμ☺☻☼♥♣♦✔♀♂♪♫✝"
+SPECIAL_CHARS_DEFAULT = "“”„‘’•◇▪▸☐☑☒★…‰€©®™°↓↑→←↔↵⇓⇑⇒⇐⇔»«▼▲►◄≤≥≠≈±¹²³½¼⅛×÷∞ø∑√∫ΔδΠπΣΦΩωαβγεηλμ☺☻☼♥♣♦✔♀♂♪♫✝"
 SELWORD_CHARS_DEFAULT = ".-@"
 TIMESTAMP_FORMAT_DEFAULT = "%Y/%m/%d - %H:%M"
 TOOLBAR_VEC_DEFAULT = ["TreeAddNode", "TreeAddSubNode", cons.TAG_SEPARATOR, "GoBack", "GoForward", cons.TAG_SEPARATOR, cons.CHAR_STAR, "Save", "Export2PDF", cons.TAG_SEPARATOR, "FindInNodes", cons.TAG_SEPARATOR, "BulletedList", "NumberedList", "ToDoList", cons.TAG_SEPARATOR, "HandleImage", "HandleTable", "HandleCodeBox", "EmbFileInsert", "HandleLink", "HandleAnchor", cons.TAG_SEPARATOR, "RemoveFormatting", "ColorForeground", "ColorBackground", "Bold", "Italic", "Underline", "Strikethrough", "H1", "H2", "H3", "Small", "Superscript", "Subscript", "Monospace"]
@@ -88,7 +88,10 @@ def config_file_load(inst):
     """Load the Preferences from Config File"""
     if os.path.isfile(cons.CONFIG_PATH):
         config = ConfigParser.RawConfigParser()
-        config.read(cons.CONFIG_PATH)
+        try:
+            config.read(cons.CONFIG_PATH)
+        except ConfigParser.MissingSectionHeaderError:
+            print "? ConfigParser.MissingSectionHeaderError"
 
         section = "state"
         inst.file_dir = unicode(config.get(section, "file_dir"), cons.STR_UTF8, cons.STR_IGNORE) if config.has_option(section, "file_dir") else ""
@@ -148,7 +151,7 @@ def config_file_load(inst):
         section = "editor"
         inst.syntax_highlighting = config.get(section, "syntax_highlighting") if config.has_option(section, "syntax_highlighting") else cons.RICH_TEXT_ID
         inst.auto_syn_highl = config.get(section, "auto_syn_highl") if config.has_option(section, "auto_syn_highl") else "sh"
-        inst.style_scheme = config.get(section, "style_scheme") if config.has_option(section, "style_scheme") else cons.STYLE_SCHEME_DEFAULT
+        inst.style_scheme = config.get(section, "style_scheme") if config.has_option(section, "style_scheme") else cons.STYLE_SCHEME_DARK
         inst.enable_spell_check = config.getboolean(section, "enable_spell_check") if config.has_option(section, "enable_spell_check") else False
         inst.spell_check_lang = config.get(section, "spell_check_lang") if config.has_option(section, "spell_check_lang") else SPELL_CHECK_LANG_DEFAULT
         inst.show_line_numbers = config.getboolean(section, "show_line_numbers") if config.has_option(section, "show_line_numbers") else False
@@ -242,7 +245,7 @@ def config_file_load(inst):
         inst.curr_colors = {'f':None, 'b':None}
         inst.syntax_highlighting = cons.RICH_TEXT_ID
         inst.auto_syn_highl = "sh"
-        inst.style_scheme = cons.STYLE_SCHEME_DEFAULT
+        inst.style_scheme = cons.STYLE_SCHEME_DARK
         inst.tree_font = "Sans 8" # default tree font
         inst.text_font = "Sans 9" # default text font
         inst.code_font = "Monospace 9" # default code font
@@ -824,14 +827,18 @@ def preferences_tab_rich_text_nodes(dad, vbox_text_nodes, pref_dialog):
         if new_lang_code != dad.spell_check_lang: dad.spell_check_set_new_lang(new_lang_code)
     combobox_spell_check_lang.connect('changed', on_combobox_spell_check_lang_changed)
     def on_colorbutton_text_fg_color_set(colorbutton):
-        dad.rt_def_fg = "#" + dad.html_handler.rgb_to_24(colorbutton.get_color().to_string()[1:])
+        dad.rt_def_fg = "#" + exports.rgb_any_to_24(colorbutton.get_color().to_string()[1:])
         if dad.curr_tree_iter and dad.syntax_highlighting == cons.RICH_TEXT_ID:
             dad.widget_set_colors(dad.sourceview, dad.rt_def_fg, dad.rt_def_bg, False)
             support.rich_text_node_modify_codeboxes_color(dad.curr_buffer.get_start_iter(), dad)
     colorbutton_text_fg.connect('color-set', on_colorbutton_text_fg_color_set)
     def on_colorbutton_text_bg_color_set(colorbutton):
-        dad.rt_def_bg = "#" + dad.html_handler.rgb_to_24(colorbutton.get_color().to_string()[1:])
+        dad.rt_def_bg = "#" + exports.rgb_any_to_24(colorbutton.get_color().to_string()[1:])
         if dad.curr_tree_iter and dad.syntax_highlighting == cons.RICH_TEXT_ID:
+            if dad.rt_highl_curr_line:
+                dad.set_sourcebuffer_with_style_scheme()
+                dad.sourceview.set_buffer(dad.curr_buffer)
+                dad.objects_buffer_refresh()
             dad.widget_set_colors(dad.sourceview, dad.rt_def_fg, dad.rt_def_bg, False)
             support.rich_text_node_modify_codeboxes_color(dad.curr_buffer.get_start_iter(), dad)
     colorbutton_text_bg.connect('color-set', on_colorbutton_text_bg_color_set)
@@ -1055,12 +1062,12 @@ def preferences_tab_tree(dad, vbox_tree, pref_dialog):
     vbox_tree.pack_start(frame_nodes_startup, expand=False)
     vbox_tree.pack_start(frame_misc_tree, expand=False)
     def on_colorbutton_tree_fg_color_set(colorbutton):
-        dad.tt_def_fg = "#" + dad.html_handler.rgb_to_24(colorbutton.get_color().to_string()[1:])
+        dad.tt_def_fg = "#" + exports.rgb_any_to_24(colorbutton.get_color().to_string()[1:])
         dad.widget_set_colors(dad.treeview, dad.tt_def_fg, dad.tt_def_bg, False)
         if dad.curr_tree_iter: dad.update_node_name_header()
     colorbutton_tree_fg.connect('color-set', on_colorbutton_tree_fg_color_set)
     def on_colorbutton_tree_bg_color_set(colorbutton):
-        dad.tt_def_bg = "#" + dad.html_handler.rgb_to_24(colorbutton.get_color().to_string()[1:])
+        dad.tt_def_bg = "#" + exports.rgb_any_to_24(colorbutton.get_color().to_string()[1:])
         dad.widget_set_colors(dad.treeview, dad.tt_def_fg, dad.tt_def_bg, False)
         if dad.curr_tree_iter: dad.update_node_name_header()
     colorbutton_tree_bg.connect('color-set', on_colorbutton_tree_bg_color_set)
